%define basen black-hole-solver
%define libname_orig lib%{basen}
%define major 1
%define libname %mklibname %{basen} %{major}
%define develname %mklibname %{basen} -d
%define staticname %mklibname %{basen} -d -s

Name: %{basen}
Version: 1.14.0
Release: %mkrel 1
License: MIT
Group: Games/Cards
Source0: https://fc-solve.shlomifish.org/downloads/fc-solve/%{basen}-%{version}.tar.xz
URL: https://www.shlomifish.org/open-source/projects/black-hole-solitaire-solver/
Requires: %{libname} = %version-%release
Summary: The Black Hole Solitaire Solver Executable
BuildRequires: cmake
BuildRequires: perl(Carp)
BuildRequires: perl(Cwd)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Dir::Manifest)
BuildRequires: perl(Env::Path)
BuildRequires: perl(File::Path)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Inline)
BuildRequires: perl(Inline::C)
BuildRequires: perl(List::MoreUtils)
BuildRequires: perl(Path::Tiny)
BuildRequires: perl(Test::Differences)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::RunValgrind)
BuildRequires: perl(Test::Some)
BuildRequires: perl(Test::Trap)
BuildRequires: perl(base)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildRequires: perl-devel
BuildRequires: pkgconfig(librinutils)
BuildRequires: python3
BuildRequires: valgrind

%description
This is a solver, written in C, to solve the Solitaire variants “Golf”,
“Black Hole” and “All in a Row”. It provides a portable C library, and
a command line application that after being fed with a layout will emit the
cards to move.

%files
%doc COPYING NEWS.asciidoc README.md TODO.quicktask
%_bindir/black-hole-solve
%{_mandir}/*/*

#--------------------------------------------------------------------

%package -n %{libname}
Summary: The Black Hole Solver dynamic libraries
Group: Games/Cards

%description -n %{libname}
Contains the Black Hole Solver libraries that are used by some programs.

This package is mandatory for the Black Hole Solver executable too.

%files -n %{libname}
%{_libdir}/libblack_hole_solver.so.%{major}{,.*}

#--------------------------------------------------------------------

%package -n %{develname}
Summary: The Black Hole Solitaire development tools
Group: Games/Cards
Requires: %{libname} = %version-%release
Provides: %{name}-devel = %{version}-%{release}

%description -n %{develname}
Development tools for the Black Hole Solitaire Solver.

%files -n %{develname}
%_includedir/black-hole-solver/*.h
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libblack_hole_solver.so

#--------------------------------------------------------------------

%package -n %{staticname}
Summary: The Black Hole Solver static libraries
Group: Games/Cards
Requires: %{develname} = %version-%release

%description -n %{staticname}
Black Hole Solitaire Solver is a library for automatically solving boards of
Golf, Black Hole, and All in a Row solitaires. This package contains the static
libraries.

It is not generally required.

%files -n %{staticname}
%{_libdir}/libblack_hole_solver.a

#--------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake -DBUILD_STATIC_LIBRARY=1 -DLOCALE_INSTALL_DIR=%{_datadir}/locale -DLIB_INSTALL_DIR=%{_libdir}
%cmake_build -j1

%check
%ifarch %arm
# valgrind suppression not working without glibc-debuginfo breaks it
rm -f t/valgrind.t
%endif
rm -f t/clang-format.t
rm -f t/perltidy.t
# fails due to build containing binaries
rm -f t/style-trailing-space.t
cd %{_vpath_builddir}
# %%make_build test
%__perl ../run-tests.pl

%install
export QA_RPATHS=0x0001
%cmake_install


%changelog
* Mon Apr 14 2025 mrambo3501 <mrambo3501> 1.14.0-1.mga10
+ Revision: 2175587
- version 1.14.0
- fix files list

* Tue Oct 11 2022 neoclust <neoclust> 1.12.0-1.mga9
+ Revision: 1896257
- New version 1.12.0

* Fri Apr 01 2022 umeabot <umeabot> 1.10.1-4.mga9
+ Revision: 1838713
- Mageia 9 Mass Rebuild

* Fri Mar 11 2022 mrambo3501 <mrambo3501> 1.10.1-3.mga9
+ Revision: 1790303
- remove the global rpath disable
- ignore the standard 0x0001 rpath

* Wed Mar 09 2022 mrambo3501 <mrambo3501> 1.10.1-2.mga9
+ Revision: 1790124
- disable rpath checking

* Wed Oct 28 2020 shlomif <shlomif> 1.10.1-1.mga8
+ Revision: 1640293
- New version 1.10.1

* Sat Jun 27 2020 shlomif <shlomif> 1.8.0-1.mga8
+ Revision: 1599683
- New version 1.8.0

* Tue Feb 18 2020 umeabot <umeabot> 1.6.0-3.mga8
+ Revision: 1541390
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Dec 26 2019 shlomif <shlomif> 1.6.0-2.mga8
+ Revision: 1470099
- adapt for new cmake macros

* Sat Dec 07 2019 shlomif <shlomif> 1.6.0-1.mga8
+ Revision: 1464896
- New version 1.6.0

* Tue Jul 16 2019 shlomif <shlomif> 1.4.0-1.mga8
+ Revision: 1421944
- New version 1.4.0

* Mon Jul 01 2019 shlomif <shlomif> 1.2.1-1.mga8
+ Revision: 1417191
- New version 1.2.1
- New version 1.2.0

* Sat Jun 29 2019 shlomif <shlomif> 1.0.0-1.mga8
+ Revision: 1415437
- New version 1.0.0

* Thu May 09 2019 shlomif <shlomif> 0.24.0-1.mga7
+ Revision: 1396936
- New version 0.24.0
- New version 0.22.0

* Wed Apr 24 2019 shlomif <shlomif> 0.20.0-3.mga7
+ Revision: 1395137
- remove unused BRs

* Wed Apr 24 2019 shlomif <shlomif> 0.20.0-2.mga7
+ Revision: 1395120
- sort the BRs
- remove unused BRs

* Tue Apr 16 2019 shlomif <shlomif> 0.20.0-1.mga7
+ Revision: 1391806
- New version 0.20.0 ; new libmajor

* Tue Jan 15 2019 shlomif <shlomif> 0.18.0-1.mga7
+ Revision: 1357271
- New version 0.18.0

* Fri Sep 21 2018 umeabot <umeabot> 0.16.0-2.mga7
+ Revision: 1295504
- Mageia 7 Mass Rebuild

* Sun Nov 12 2017 shlomif <shlomif> 0.16.0-1.mga7
+ Revision: 1177029
- New version w some fixes.

* Sun Feb 28 2016 pterjan <pterjan> 0.14.0-2.mga6
+ Revision: 980222
- Disable valgrind test on arm, false positive

* Wed Feb 24 2016 shlomif <shlomif> 0.14.0-1.mga6
+ Revision: 978645
- Importing black-hole-solver based on freecell-solver

